@@ -4,10 +4,11 @@ from curses import ascii
 
 from fontbro.features import FEATURES as _FEATURES_LIST
 from fontbro.flags import get_flag, set_flag
-from fontbro.uni import (
+from fontbro.unicodedata import (
     UNICODE_BLOCKS as _UNICODE_BLOCKS,
     UNICODE_SCRIPTS as _UNICODE_SCRIPTS,
 )
+from fontbro.utils import slugify
 
 from fontTools import unicodedata
 from fontTools.subset import parse_unicodes, Subsetter
@@ -20,6 +21,7 @@ import fsutil
 import itertools
 import math
 import os
+import re
 import sys
 
 
@@ -236,25 +238,29 @@ class Font(object):
         font = self.get_ttfont()
         cmap = font.getBestCmap()
         for code, char_name in cmap.items():
+            code_hex = f"{code:04X}"
             char = chr(code)
             if ascii.iscntrl(char):
                 continue
-            name = ""
             try:
-                name = unicodedata.name(char)
+                unicode_name = unicodedata.name(char)
             except ValueError:
                 pass
-            block_name = unicodedata.block(code)
-            script_tag = unicodedata.script(code)
-            script_name = unicodedata.script_name(script_tag)
+            unicode_block_name = unicodedata.block(code)
+            unicode_script_tag = unicodedata.script(code)
+            unicode_script_name = unicodedata.script_name(unicode_script_tag)
             yield {
                 "character": char,
                 "character_name": char_name,
                 "code": code,
-                "name": name,
-                "block_name": block_name,
-                "script_name": script_name,
-                "script_tag": script_tag,
+                "escape_sequence": f"\\u{code_hex}",
+                "html_code": "&#{code};",
+                "unicode": f"U+{code_hex}",
+                "unicode_code": code,
+                "unicode_name": unicode_name,
+                "unicode_block_name": unicode_block_name,
+                "unicode_script_name": unicode_script_name,
+                "unicode_script_tag": unicode_script_tag,
             }
 
     def get_characters_count(self):
@@ -437,10 +443,29 @@ class Font(object):
             else:
                 item["characters_count"] = 0
                 item["coverage"] = 0.0
-        items_filtered = [item for item in all_items if item["coverage"] >= coverage_threshold]
+        items_filtered = [
+            item for item in all_items if item["coverage"] >= coverage_threshold
+        ]
         # items_filtered.sort(key=lambda item: item['name'])
         return items_filtered
 
+    def get_unicode_block_by_name(self, name):
+        """
+        Gets the unicode block by name (name is case-insensitive and ignores "-").
+
+        :param name: The name
+        :type name: str
+
+        :returns: The unicode block dict if the name is valid, None otherwise.
+        :rtype: dict or None
+        """
+        blocks = self.get_unicode_blocks(coverage_threshold=0.0)
+        for block in blocks:
+            if slugify(name) == slugify(block["name"]):
+                return block
+        # raise KeyError("Invalid unicode block name: '{name}'")
+        return None
+
     def get_unicode_blocks(self, coverage_threshold=0.00001):
         """
         Gets the unicode blocks and their coverage.
@@ -456,7 +481,7 @@ class Font(object):
         items_cache = {}
         for char in self.get_characters():
             item = {
-                "name": char["block_name"],
+                "name": char["unicode_block_name"],
             }
             self._populate_unicode_items_set(items, items_cache, item)
         blocks = self._get_unicode_items_set_with_coverage(
@@ -464,6 +489,23 @@ class Font(object):
         )
         return blocks
 
+    def get_unicode_script_by_name(self, name):
+        """
+        Gets the unicode script by name/tag (name/tag is case-insensitive and ignores "-").
+
+        :param name: The name
+        :type name: str
+
+        :returns: The unicode script dict if the name/tag is valid, None otherwise.
+        :rtype: dict or None
+        """
+        scripts = self.get_unicode_scripts(coverage_threshold=0.0)
+        for script in scripts:
+            if slugify(name) in (slugify(script["name"]), slugify(script["tag"])):
+                return script
+        # raise KeyError("Invalid unicode script name/tag: '{name}'")
+        return None
+
     def get_unicode_scripts(self, coverage_threshold=0.00001):
         """
         Gets the unicode scripts and their coverage.
@@ -479,8 +521,8 @@ class Font(object):
         items_cache = {}
         for char in self.get_characters():
             item = {
-                "name": char["script_name"],
-                "tag": char["script_tag"],
+                "name": char["unicode_script_name"],
+                "tag": char["unicode_script_tag"],
             }
             self._populate_unicode_items_set(items, items_cache, item)
         scripts = self._get_unicode_items_set_with_coverage(
@@ -526,6 +568,7 @@ class Font(object):
             for axis in axes:
                 if axis.get("tag") == tag:
                     return axis
+        # raise KeyError("Invalid axis tag: '{tag}'")
         return None
 
     def get_variable_axes_tags(self):
@@ -867,6 +910,19 @@ class Font(object):
                 assert isinstance(value, bool)
                 self.set_style_flag(key, value)
 
+    @staticmethod
+    def _get_unicodes(unicodes):
+        unicodes = unicodes or ""
+        if isinstance(unicodes, (list, set, tuple)):
+            unicodes = ",".join(list(set(unicodes)))
+        # replace possible — ‐ − (&mdash; &dash; &minus;) with -
+        # remove U+ and \u if present
+        unicodes = re.sub(r"[\—\‐\−]", "-", unicodes)
+        unicodes = re.sub(r"(U\+)|(\\u)", "", unicodes)
+        unicodes = parse_unicodes(unicodes)
+        # print(unicodes)
+        return unicodes
+
     def subset(self, unicodes="", glyphs=[], text="", **options):
         """
         Subsets the font using the given options (unicodes or glyphs or text),
@@ -888,13 +944,7 @@ class Font(object):
                 "Subsetting requires at least one of the following args: unicode,"
                 " glyphs, text."
             )
-        if isinstance(unicodes, (list, set, tuple)):
-            unicodes = ", ".join(list(unicodes))
-        # replace possible — ‐ − (&mdash; &dash; &minus;) with -
-        for s in ("—", "‐", "−"):
-            unicodes = unicodes.replace(s, "-")
-        unicodes = parse_unicodes(unicodes)
-        # print(unicodes)
+        unicodes = self._get_unicodes(unicodes)
         subs_args = {"unicodes": unicodes, "glyphs": glyphs, "text": text}
         # https://github.com/fonttools/fonttools/blob/main/Lib/fontTools/subset/__init__.py
         subs = Subsetter(**options)
